// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: attr_value.proto
// Protobuf C++ Version: 6.32.1

#ifndef attr_5fvalue_2eproto_2epb_2eh
#define attr_5fvalue_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 6032001
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/map.h"  // IWYU pragma: export
#include "google/protobuf/map_type_handler.h"  // IWYU pragma: export
#include "google/protobuf/map_entry.h"
#include "google/protobuf/map_field.h"
#include "google/protobuf/unknown_field_set.h"
#include "tensor.pb.h"
#include "tensor_shape.pb.h"
#include "types.pb.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_attr_5fvalue_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_attr_5fvalue_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_attr_5fvalue_2eproto;
}  // extern "C"
namespace opencv_tensorflow {
class AttrValue;
struct AttrValueDefaultTypeInternal;
extern AttrValueDefaultTypeInternal _AttrValue_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull AttrValue_class_data_;
class AttrValue_ListValue;
struct AttrValue_ListValueDefaultTypeInternal;
extern AttrValue_ListValueDefaultTypeInternal _AttrValue_ListValue_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull AttrValue_ListValue_class_data_;
class NameAttrList;
struct NameAttrListDefaultTypeInternal;
extern NameAttrListDefaultTypeInternal _NameAttrList_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull NameAttrList_class_data_;
class NameAttrList_AttrEntry_DoNotUse;
struct NameAttrList_AttrEntry_DoNotUseDefaultTypeInternal;
extern NameAttrList_AttrEntry_DoNotUseDefaultTypeInternal _NameAttrList_AttrEntry_DoNotUse_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull NameAttrList_AttrEntry_DoNotUse_class_data_;
}  // namespace opencv_tensorflow
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google

namespace opencv_tensorflow {

// ===================================================================


// -------------------------------------------------------------------

class AttrValue_ListValue final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:opencv_tensorflow.AttrValue.ListValue) */ {
 public:
  inline AttrValue_ListValue() : AttrValue_ListValue(nullptr) {}
  ~AttrValue_ListValue() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(AttrValue_ListValue* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(AttrValue_ListValue));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR AttrValue_ListValue(::google::protobuf::internal::ConstantInitialized);

  inline AttrValue_ListValue(const AttrValue_ListValue& from) : AttrValue_ListValue(nullptr, from) {}
  inline AttrValue_ListValue(AttrValue_ListValue&& from) noexcept
      : AttrValue_ListValue(nullptr, ::std::move(from)) {}
  inline AttrValue_ListValue& operator=(const AttrValue_ListValue& from) {
    CopyFrom(from);
    return *this;
  }
  inline AttrValue_ListValue& operator=(AttrValue_ListValue&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const AttrValue_ListValue& default_instance() {
    return *reinterpret_cast<const AttrValue_ListValue*>(
        &_AttrValue_ListValue_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(AttrValue_ListValue& a, AttrValue_ListValue& b) { a.Swap(&b); }
  inline void Swap(AttrValue_ListValue* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(AttrValue_ListValue* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  AttrValue_ListValue* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<AttrValue_ListValue>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const AttrValue_ListValue& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const AttrValue_ListValue& from) { AttrValue_ListValue::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(AttrValue_ListValue* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "opencv_tensorflow.AttrValue.ListValue"; }

 protected:
  explicit AttrValue_ListValue(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  AttrValue_ListValue(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const AttrValue_ListValue& from);
  AttrValue_ListValue(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, AttrValue_ListValue&& from) noexcept
      : AttrValue_ListValue(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kSFieldNumber = 2,
    kIFieldNumber = 3,
    kFFieldNumber = 4,
    kBFieldNumber = 5,
    kTypeFieldNumber = 6,
    kShapeFieldNumber = 7,
    kTensorFieldNumber = 8,
  };
  // repeated bytes s = 2;
  int s_size() const;
  private:
  int _internal_s_size() const;

  public:
  void clear_s() ;
  const ::std::string& s(int index) const;
  ::std::string* PROTOBUF_NONNULL mutable_s(int index);
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_s(int index, Arg_&& value, Args_... args);
  ::std::string* PROTOBUF_NONNULL add_s();
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void add_s(Arg_&& value, Args_... args);
  const ::google::protobuf::RepeatedPtrField<::std::string>& s() const;
  ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL mutable_s();

  private:
  const ::google::protobuf::RepeatedPtrField<::std::string>& _internal_s() const;
  ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL _internal_mutable_s();

  public:
  // repeated int64 i = 3 [packed = true];
  int i_size() const;
  private:
  int _internal_i_size() const;

  public:
  void clear_i() ;
  ::int64_t i(int index) const;
  void set_i(int index, ::int64_t value);
  void add_i(::int64_t value);
  const ::google::protobuf::RepeatedField<::int64_t>& i() const;
  ::google::protobuf::RepeatedField<::int64_t>* PROTOBUF_NONNULL mutable_i();

  private:
  const ::google::protobuf::RepeatedField<::int64_t>& _internal_i() const;
  ::google::protobuf::RepeatedField<::int64_t>* PROTOBUF_NONNULL _internal_mutable_i();

  public:
  // repeated float f = 4 [packed = true];
  int f_size() const;
  private:
  int _internal_f_size() const;

  public:
  void clear_f() ;
  float f(int index) const;
  void set_f(int index, float value);
  void add_f(float value);
  const ::google::protobuf::RepeatedField<float>& f() const;
  ::google::protobuf::RepeatedField<float>* PROTOBUF_NONNULL mutable_f();

  private:
  const ::google::protobuf::RepeatedField<float>& _internal_f() const;
  ::google::protobuf::RepeatedField<float>* PROTOBUF_NONNULL _internal_mutable_f();

  public:
  // repeated bool b = 5 [packed = true];
  int b_size() const;
  private:
  int _internal_b_size() const;

  public:
  void clear_b() ;
  bool b(int index) const;
  void set_b(int index, bool value);
  void add_b(bool value);
  const ::google::protobuf::RepeatedField<bool>& b() const;
  ::google::protobuf::RepeatedField<bool>* PROTOBUF_NONNULL mutable_b();

  private:
  const ::google::protobuf::RepeatedField<bool>& _internal_b() const;
  ::google::protobuf::RepeatedField<bool>* PROTOBUF_NONNULL _internal_mutable_b();

  public:
  // repeated .opencv_tensorflow.DataType type = 6 [packed = true];
  int type_size() const;
  private:
  int _internal_type_size() const;

  public:
  void clear_type() ;
  public:
  ::opencv_tensorflow::DataType type(int index) const;
  void set_type(int index, ::opencv_tensorflow::DataType value);
  void add_type(::opencv_tensorflow::DataType value);
  const ::google::protobuf::RepeatedField<int>& type() const;
  ::google::protobuf::RepeatedField<int>* PROTOBUF_NONNULL mutable_type();

  private:
  const ::google::protobuf::RepeatedField<int>& _internal_type() const;
  ::google::protobuf::RepeatedField<int>* PROTOBUF_NONNULL _internal_mutable_type();

  public:
  // repeated .opencv_tensorflow.TensorShapeProto shape = 7;
  int shape_size() const;
  private:
  int _internal_shape_size() const;

  public:
  void clear_shape() ;
  ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NONNULL mutable_shape(int index);
  ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorShapeProto>* PROTOBUF_NONNULL mutable_shape();

  private:
  const ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorShapeProto>& _internal_shape() const;
  ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorShapeProto>* PROTOBUF_NONNULL _internal_mutable_shape();
  public:
  const ::opencv_tensorflow::TensorShapeProto& shape(int index) const;
  ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NONNULL add_shape();
  const ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorShapeProto>& shape() const;
  // repeated .opencv_tensorflow.TensorProto tensor = 8;
  int tensor_size() const;
  private:
  int _internal_tensor_size() const;

  public:
  void clear_tensor() ;
  ::opencv_tensorflow::TensorProto* PROTOBUF_NONNULL mutable_tensor(int index);
  ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorProto>* PROTOBUF_NONNULL mutable_tensor();

  private:
  const ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorProto>& _internal_tensor() const;
  ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorProto>* PROTOBUF_NONNULL _internal_mutable_tensor();
  public:
  const ::opencv_tensorflow::TensorProto& tensor(int index) const;
  ::opencv_tensorflow::TensorProto* PROTOBUF_NONNULL add_tensor();
  const ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorProto>& tensor() const;
  // @@protoc_insertion_point(class_scope:opencv_tensorflow.AttrValue.ListValue)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<3, 7,
                                   2, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const AttrValue_ListValue& from_msg);
    ::google::protobuf::RepeatedPtrField<::std::string> s_;
    ::google::protobuf::RepeatedField<::int64_t> i_;
    ::google::protobuf::internal::CachedSize _i_cached_byte_size_;
    ::google::protobuf::RepeatedField<float> f_;
    ::google::protobuf::RepeatedField<bool> b_;
    ::google::protobuf::RepeatedField<int> type_;
    ::google::protobuf::internal::CachedSize _type_cached_byte_size_;
    ::google::protobuf::RepeatedPtrField< ::opencv_tensorflow::TensorShapeProto > shape_;
    ::google::protobuf::RepeatedPtrField< ::opencv_tensorflow::TensorProto > tensor_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_attr_5fvalue_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull AttrValue_ListValue_class_data_;
// -------------------------------------------------------------------

class AttrValue final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:opencv_tensorflow.AttrValue) */ {
 public:
  inline AttrValue() : AttrValue(nullptr) {}
  ~AttrValue() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(AttrValue* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(AttrValue));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR AttrValue(::google::protobuf::internal::ConstantInitialized);

  inline AttrValue(const AttrValue& from) : AttrValue(nullptr, from) {}
  inline AttrValue(AttrValue&& from) noexcept
      : AttrValue(nullptr, ::std::move(from)) {}
  inline AttrValue& operator=(const AttrValue& from) {
    CopyFrom(from);
    return *this;
  }
  inline AttrValue& operator=(AttrValue&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const AttrValue& default_instance() {
    return *reinterpret_cast<const AttrValue*>(
        &_AttrValue_default_instance_);
  }
  enum ValueCase {
    kS = 2,
    kI = 3,
    kF = 4,
    kB = 5,
    kType = 6,
    kShape = 7,
    kTensor = 8,
    kList = 1,
    kFunc = 10,
    kPlaceholder = 9,
    VALUE_NOT_SET = 0,
  };
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(AttrValue& a, AttrValue& b) { a.Swap(&b); }
  inline void Swap(AttrValue* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(AttrValue* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  AttrValue* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<AttrValue>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const AttrValue& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const AttrValue& from) { AttrValue::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(AttrValue* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "opencv_tensorflow.AttrValue"; }

 protected:
  explicit AttrValue(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  AttrValue(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const AttrValue& from);
  AttrValue(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, AttrValue&& from) noexcept
      : AttrValue(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------
  using ListValue = AttrValue_ListValue;

  // accessors -------------------------------------------------------
  enum : int {
    kSFieldNumber = 2,
    kIFieldNumber = 3,
    kFFieldNumber = 4,
    kBFieldNumber = 5,
    kTypeFieldNumber = 6,
    kShapeFieldNumber = 7,
    kTensorFieldNumber = 8,
    kListFieldNumber = 1,
    kFuncFieldNumber = 10,
    kPlaceholderFieldNumber = 9,
  };
  // bytes s = 2;
  bool has_s() const;
  void clear_s() ;
  const ::std::string& s() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_s(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_s();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_s();
  void set_allocated_s(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_s() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_s(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_s();

  public:
  // int64 i = 3;
  bool has_i() const;
  void clear_i() ;
  ::int64_t i() const;
  void set_i(::int64_t value);

  private:
  ::int64_t _internal_i() const;
  void _internal_set_i(::int64_t value);

  public:
  // float f = 4;
  bool has_f() const;
  void clear_f() ;
  float f() const;
  void set_f(float value);

  private:
  float _internal_f() const;
  void _internal_set_f(float value);

  public:
  // bool b = 5;
  bool has_b() const;
  void clear_b() ;
  bool b() const;
  void set_b(bool value);

  private:
  bool _internal_b() const;
  void _internal_set_b(bool value);

  public:
  // .opencv_tensorflow.DataType type = 6;
  bool has_type() const;
  void clear_type() ;
  ::opencv_tensorflow::DataType type() const;
  void set_type(::opencv_tensorflow::DataType value);

  private:
  ::opencv_tensorflow::DataType _internal_type() const;
  void _internal_set_type(::opencv_tensorflow::DataType value);

  public:
  // .opencv_tensorflow.TensorShapeProto shape = 7;
  bool has_shape() const;
  private:
  bool _internal_has_shape() const;

  public:
  void clear_shape() ;
  const ::opencv_tensorflow::TensorShapeProto& shape() const;
  [[nodiscard]] ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NULLABLE release_shape();
  ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NONNULL mutable_shape();
  void set_allocated_shape(::opencv_tensorflow::TensorShapeProto* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_shape(::opencv_tensorflow::TensorShapeProto* PROTOBUF_NULLABLE value);
  ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NULLABLE unsafe_arena_release_shape();

  private:
  const ::opencv_tensorflow::TensorShapeProto& _internal_shape() const;
  ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NONNULL _internal_mutable_shape();

  public:
  // .opencv_tensorflow.TensorProto tensor = 8;
  bool has_tensor() const;
  private:
  bool _internal_has_tensor() const;

  public:
  void clear_tensor() ;
  const ::opencv_tensorflow::TensorProto& tensor() const;
  [[nodiscard]] ::opencv_tensorflow::TensorProto* PROTOBUF_NULLABLE release_tensor();
  ::opencv_tensorflow::TensorProto* PROTOBUF_NONNULL mutable_tensor();
  void set_allocated_tensor(::opencv_tensorflow::TensorProto* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_tensor(::opencv_tensorflow::TensorProto* PROTOBUF_NULLABLE value);
  ::opencv_tensorflow::TensorProto* PROTOBUF_NULLABLE unsafe_arena_release_tensor();

  private:
  const ::opencv_tensorflow::TensorProto& _internal_tensor() const;
  ::opencv_tensorflow::TensorProto* PROTOBUF_NONNULL _internal_mutable_tensor();

  public:
  // .opencv_tensorflow.AttrValue.ListValue list = 1;
  bool has_list() const;
  private:
  bool _internal_has_list() const;

  public:
  void clear_list() ;
  const ::opencv_tensorflow::AttrValue_ListValue& list() const;
  [[nodiscard]] ::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NULLABLE release_list();
  ::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NONNULL mutable_list();
  void set_allocated_list(::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_list(::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NULLABLE value);
  ::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NULLABLE unsafe_arena_release_list();

  private:
  const ::opencv_tensorflow::AttrValue_ListValue& _internal_list() const;
  ::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NONNULL _internal_mutable_list();

  public:
  // .opencv_tensorflow.NameAttrList func = 10;
  bool has_func() const;
  private:
  bool _internal_has_func() const;

  public:
  void clear_func() ;
  const ::opencv_tensorflow::NameAttrList& func() const;
  [[nodiscard]] ::opencv_tensorflow::NameAttrList* PROTOBUF_NULLABLE release_func();
  ::opencv_tensorflow::NameAttrList* PROTOBUF_NONNULL mutable_func();
  void set_allocated_func(::opencv_tensorflow::NameAttrList* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_func(::opencv_tensorflow::NameAttrList* PROTOBUF_NULLABLE value);
  ::opencv_tensorflow::NameAttrList* PROTOBUF_NULLABLE unsafe_arena_release_func();

  private:
  const ::opencv_tensorflow::NameAttrList& _internal_func() const;
  ::opencv_tensorflow::NameAttrList* PROTOBUF_NONNULL _internal_mutable_func();

  public:
  // string placeholder = 9;
  bool has_placeholder() const;
  void clear_placeholder() ;
  const ::std::string& placeholder() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_placeholder(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_placeholder();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_placeholder();
  void set_allocated_placeholder(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_placeholder() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_placeholder(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_placeholder();

  public:
  void clear_value();
  ValueCase value_case() const;
  // @@protoc_insertion_point(class_scope:opencv_tensorflow.AttrValue)
 private:
  class _Internal;
  void set_has_s();
  void set_has_i();
  void set_has_f();
  void set_has_b();
  void set_has_type();
  void set_has_shape();
  void set_has_tensor();
  void set_has_list();
  void set_has_func();
  void set_has_placeholder();
  inline bool has_value() const;
  inline void clear_has_value();
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 10,
                                   4, 55,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const AttrValue& from_msg);
    union ValueUnion {
      constexpr ValueUnion() : _constinit_{} {}
      ::google::protobuf::internal::ConstantInitialized _constinit_;
      ::google::protobuf::internal::ArenaStringPtr s_;
      ::int64_t i_;
      float f_;
      bool b_;
      int type_;
      ::google::protobuf::Message* PROTOBUF_NULLABLE shape_;
      ::google::protobuf::Message* PROTOBUF_NULLABLE tensor_;
      ::google::protobuf::Message* PROTOBUF_NULLABLE list_;
      ::google::protobuf::Message* PROTOBUF_NULLABLE func_;
      ::google::protobuf::internal::ArenaStringPtr placeholder_;
    } value_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::uint32_t _oneof_case_[1];
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_attr_5fvalue_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull AttrValue_class_data_;
// -------------------------------------------------------------------

class NameAttrList final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:opencv_tensorflow.NameAttrList) */ {
 public:
  inline NameAttrList() : NameAttrList(nullptr) {}
  ~NameAttrList() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(NameAttrList* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(NameAttrList));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR NameAttrList(::google::protobuf::internal::ConstantInitialized);

  inline NameAttrList(const NameAttrList& from) : NameAttrList(nullptr, from) {}
  inline NameAttrList(NameAttrList&& from) noexcept
      : NameAttrList(nullptr, ::std::move(from)) {}
  inline NameAttrList& operator=(const NameAttrList& from) {
    CopyFrom(from);
    return *this;
  }
  inline NameAttrList& operator=(NameAttrList&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const NameAttrList& default_instance() {
    return *reinterpret_cast<const NameAttrList*>(
        &_NameAttrList_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 3;
  friend void swap(NameAttrList& a, NameAttrList& b) { a.Swap(&b); }
  inline void Swap(NameAttrList* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(NameAttrList* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  NameAttrList* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<NameAttrList>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const NameAttrList& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const NameAttrList& from) { NameAttrList::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(NameAttrList* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "opencv_tensorflow.NameAttrList"; }

 protected:
  explicit NameAttrList(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  NameAttrList(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const NameAttrList& from);
  NameAttrList(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, NameAttrList&& from) noexcept
      : NameAttrList(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kAttrFieldNumber = 2,
    kNameFieldNumber = 1,
  };
  // map<string, .opencv_tensorflow.AttrValue> attr = 2;
  int attr_size() const;
  private:
  int _internal_attr_size() const;

  public:
  void clear_attr() ;
  const ::google::protobuf::Map<::std::string, ::opencv_tensorflow::AttrValue>& attr() const;
  ::google::protobuf::Map<::std::string, ::opencv_tensorflow::AttrValue>* PROTOBUF_NONNULL mutable_attr();

  private:
  const ::google::protobuf::Map<::std::string, ::opencv_tensorflow::AttrValue>& _internal_attr() const;
  ::google::protobuf::Map<::std::string, ::opencv_tensorflow::AttrValue>* PROTOBUF_NONNULL _internal_mutable_attr();

  public:
  // string name = 1;
  void clear_name() ;
  const ::std::string& name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_name();
  void set_allocated_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_name();

  public:
  // @@protoc_insertion_point(class_scope:opencv_tensorflow.NameAttrList)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 2,
                                   2, 47,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const NameAttrList& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::MapField<NameAttrList_AttrEntry_DoNotUse, ::std::string, ::opencv_tensorflow::AttrValue,
                      ::google::protobuf::internal::WireFormatLite::TYPE_STRING,
                      ::google::protobuf::internal::WireFormatLite::TYPE_MESSAGE>
        attr_;
    ::google::protobuf::internal::ArenaStringPtr name_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_attr_5fvalue_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull NameAttrList_class_data_;
// -------------------------------------------------------------------

class NameAttrList_AttrEntry_DoNotUse final
    : public ::google::protobuf::internal::MapEntry<::std::string, ::google::protobuf::Message,
                             ::google::protobuf::internal::WireFormatLite::TYPE_STRING,
                             ::google::protobuf::internal::WireFormatLite::TYPE_MESSAGE> {
 public:
  using SuperType =
      ::google::protobuf::internal::MapEntry<::std::string, ::google::protobuf::Message,
                      ::google::protobuf::internal::WireFormatLite::TYPE_STRING,
                      ::google::protobuf::internal::WireFormatLite::TYPE_MESSAGE>;
  NameAttrList_AttrEntry_DoNotUse();
  template <typename = void>
  explicit PROTOBUF_CONSTEXPR NameAttrList_AttrEntry_DoNotUse(::google::protobuf::internal::ConstantInitialized);
  explicit NameAttrList_AttrEntry_DoNotUse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr const void* PROTOBUF_NONNULL internal_default_instance() {
    return &_NameAttrList_AttrEntry_DoNotUse_default_instance_;
  }


  static constexpr auto InternalGenerateClassData_();

 private:
  friend class ::google::protobuf::MessageLite;
  friend struct ::TableStruct_attr_5fvalue_2eproto;

  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<1, 2,
                                   1, 52,
                                   2>
      _table_;

  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();
};
extern const ::google::protobuf::internal::ClassDataFull NameAttrList_AttrEntry_DoNotUse_class_data_;

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// AttrValue_ListValue

// repeated bytes s = 2;
inline int AttrValue_ListValue::_internal_s_size() const {
  return _internal_s().size();
}
inline int AttrValue_ListValue::s_size() const {
  return _internal_s_size();
}
inline void AttrValue_ListValue::clear_s() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.s_.Clear();
}
inline ::std::string* PROTOBUF_NONNULL AttrValue_ListValue::add_s()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::std::string* _s = _internal_mutable_s()->Add();
  // @@protoc_insertion_point(field_add_mutable:opencv_tensorflow.AttrValue.ListValue.s)
  return _s;
}
inline const ::std::string& AttrValue_ListValue::s(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.ListValue.s)
  return _internal_s().Get(index);
}
inline ::std::string* PROTOBUF_NONNULL AttrValue_ListValue::mutable_s(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opencv_tensorflow.AttrValue.ListValue.s)
  return _internal_mutable_s()->Mutable(index);
}
template <typename Arg_, typename... Args_>
inline void AttrValue_ListValue::set_s(int index, Arg_&& value, Args_... args) {
  ::google::protobuf::internal::AssignToString(*_internal_mutable_s()->Mutable(index), ::std::forward<Arg_>(value),
                        args... , ::google::protobuf::internal::BytesTag{});
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.ListValue.s)
}
template <typename Arg_, typename... Args_>
inline void AttrValue_ListValue::add_s(Arg_&& value, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::google::protobuf::internal::AddToRepeatedPtrField(*_internal_mutable_s(),
                               ::std::forward<Arg_>(value),
                               args... , ::google::protobuf::internal::BytesTag{});
  // @@protoc_insertion_point(field_add:opencv_tensorflow.AttrValue.ListValue.s)
}
inline const ::google::protobuf::RepeatedPtrField<::std::string>& AttrValue_ListValue::s()
    const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opencv_tensorflow.AttrValue.ListValue.s)
  return _internal_s();
}
inline ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL
AttrValue_ListValue::mutable_s() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:opencv_tensorflow.AttrValue.ListValue.s)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_s();
}
inline const ::google::protobuf::RepeatedPtrField<::std::string>&
AttrValue_ListValue::_internal_s() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.s_;
}
inline ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL
AttrValue_ListValue::_internal_mutable_s() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.s_;
}

// repeated int64 i = 3 [packed = true];
inline int AttrValue_ListValue::_internal_i_size() const {
  return _internal_i().size();
}
inline int AttrValue_ListValue::i_size() const {
  return _internal_i_size();
}
inline void AttrValue_ListValue::clear_i() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.i_.Clear();
}
inline ::int64_t AttrValue_ListValue::i(int index) const {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.ListValue.i)
  return _internal_i().Get(index);
}
inline void AttrValue_ListValue::set_i(int index, ::int64_t value) {
  _internal_mutable_i()->Set(index, value);
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.ListValue.i)
}
inline void AttrValue_ListValue::add_i(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_i()->Add(value);
  // @@protoc_insertion_point(field_add:opencv_tensorflow.AttrValue.ListValue.i)
}
inline const ::google::protobuf::RepeatedField<::int64_t>& AttrValue_ListValue::i() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opencv_tensorflow.AttrValue.ListValue.i)
  return _internal_i();
}
inline ::google::protobuf::RepeatedField<::int64_t>* PROTOBUF_NONNULL AttrValue_ListValue::mutable_i()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:opencv_tensorflow.AttrValue.ListValue.i)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_i();
}
inline const ::google::protobuf::RepeatedField<::int64_t>&
AttrValue_ListValue::_internal_i() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.i_;
}
inline ::google::protobuf::RepeatedField<::int64_t>* PROTOBUF_NONNULL
AttrValue_ListValue::_internal_mutable_i() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.i_;
}

// repeated float f = 4 [packed = true];
inline int AttrValue_ListValue::_internal_f_size() const {
  return _internal_f().size();
}
inline int AttrValue_ListValue::f_size() const {
  return _internal_f_size();
}
inline void AttrValue_ListValue::clear_f() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.f_.Clear();
}
inline float AttrValue_ListValue::f(int index) const {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.ListValue.f)
  return _internal_f().Get(index);
}
inline void AttrValue_ListValue::set_f(int index, float value) {
  _internal_mutable_f()->Set(index, value);
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.ListValue.f)
}
inline void AttrValue_ListValue::add_f(float value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_f()->Add(value);
  // @@protoc_insertion_point(field_add:opencv_tensorflow.AttrValue.ListValue.f)
}
inline const ::google::protobuf::RepeatedField<float>& AttrValue_ListValue::f() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opencv_tensorflow.AttrValue.ListValue.f)
  return _internal_f();
}
inline ::google::protobuf::RepeatedField<float>* PROTOBUF_NONNULL AttrValue_ListValue::mutable_f()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:opencv_tensorflow.AttrValue.ListValue.f)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_f();
}
inline const ::google::protobuf::RepeatedField<float>&
AttrValue_ListValue::_internal_f() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.f_;
}
inline ::google::protobuf::RepeatedField<float>* PROTOBUF_NONNULL
AttrValue_ListValue::_internal_mutable_f() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.f_;
}

// repeated bool b = 5 [packed = true];
inline int AttrValue_ListValue::_internal_b_size() const {
  return _internal_b().size();
}
inline int AttrValue_ListValue::b_size() const {
  return _internal_b_size();
}
inline void AttrValue_ListValue::clear_b() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.b_.Clear();
}
inline bool AttrValue_ListValue::b(int index) const {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.ListValue.b)
  return _internal_b().Get(index);
}
inline void AttrValue_ListValue::set_b(int index, bool value) {
  _internal_mutable_b()->Set(index, value);
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.ListValue.b)
}
inline void AttrValue_ListValue::add_b(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_b()->Add(value);
  // @@protoc_insertion_point(field_add:opencv_tensorflow.AttrValue.ListValue.b)
}
inline const ::google::protobuf::RepeatedField<bool>& AttrValue_ListValue::b() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opencv_tensorflow.AttrValue.ListValue.b)
  return _internal_b();
}
inline ::google::protobuf::RepeatedField<bool>* PROTOBUF_NONNULL AttrValue_ListValue::mutable_b()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:opencv_tensorflow.AttrValue.ListValue.b)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_b();
}
inline const ::google::protobuf::RepeatedField<bool>&
AttrValue_ListValue::_internal_b() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.b_;
}
inline ::google::protobuf::RepeatedField<bool>* PROTOBUF_NONNULL
AttrValue_ListValue::_internal_mutable_b() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.b_;
}

// repeated .opencv_tensorflow.DataType type = 6 [packed = true];
inline int AttrValue_ListValue::_internal_type_size() const {
  return _internal_type().size();
}
inline int AttrValue_ListValue::type_size() const {
  return _internal_type_size();
}
inline void AttrValue_ListValue::clear_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_.Clear();
}
inline ::opencv_tensorflow::DataType AttrValue_ListValue::type(int index) const {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.ListValue.type)
  return static_cast<::opencv_tensorflow::DataType>(_internal_type().Get(index));
}
inline void AttrValue_ListValue::set_type(int index, ::opencv_tensorflow::DataType value) {
  _internal_mutable_type()->Set(index, value);
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.ListValue.type)
}
inline void AttrValue_ListValue::add_type(::opencv_tensorflow::DataType value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_type()->Add(value);
  // @@protoc_insertion_point(field_add:opencv_tensorflow.AttrValue.ListValue.type)
}
inline const ::google::protobuf::RepeatedField<int>& AttrValue_ListValue::type() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opencv_tensorflow.AttrValue.ListValue.type)
  return _internal_type();
}
inline ::google::protobuf::RepeatedField<int>* PROTOBUF_NONNULL AttrValue_ListValue::mutable_type()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:opencv_tensorflow.AttrValue.ListValue.type)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_type();
}
inline const ::google::protobuf::RepeatedField<int>& AttrValue_ListValue::_internal_type()
    const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.type_;
}
inline ::google::protobuf::RepeatedField<int>* PROTOBUF_NONNULL
AttrValue_ListValue::_internal_mutable_type() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.type_;
}

// repeated .opencv_tensorflow.TensorShapeProto shape = 7;
inline int AttrValue_ListValue::_internal_shape_size() const {
  return _internal_shape().size();
}
inline int AttrValue_ListValue::shape_size() const {
  return _internal_shape_size();
}
inline ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NONNULL AttrValue_ListValue::mutable_shape(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opencv_tensorflow.AttrValue.ListValue.shape)
  return _internal_mutable_shape()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorShapeProto>* PROTOBUF_NONNULL AttrValue_ListValue::mutable_shape()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:opencv_tensorflow.AttrValue.ListValue.shape)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_shape();
}
inline const ::opencv_tensorflow::TensorShapeProto& AttrValue_ListValue::shape(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.ListValue.shape)
  return _internal_shape().Get(index);
}
inline ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NONNULL AttrValue_ListValue::add_shape()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::opencv_tensorflow::TensorShapeProto* _add = _internal_mutable_shape()->Add();
  // @@protoc_insertion_point(field_add:opencv_tensorflow.AttrValue.ListValue.shape)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorShapeProto>& AttrValue_ListValue::shape() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opencv_tensorflow.AttrValue.ListValue.shape)
  return _internal_shape();
}
inline const ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorShapeProto>&
AttrValue_ListValue::_internal_shape() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.shape_;
}
inline ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorShapeProto>* PROTOBUF_NONNULL
AttrValue_ListValue::_internal_mutable_shape() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.shape_;
}

// repeated .opencv_tensorflow.TensorProto tensor = 8;
inline int AttrValue_ListValue::_internal_tensor_size() const {
  return _internal_tensor().size();
}
inline int AttrValue_ListValue::tensor_size() const {
  return _internal_tensor_size();
}
inline ::opencv_tensorflow::TensorProto* PROTOBUF_NONNULL AttrValue_ListValue::mutable_tensor(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opencv_tensorflow.AttrValue.ListValue.tensor)
  return _internal_mutable_tensor()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorProto>* PROTOBUF_NONNULL AttrValue_ListValue::mutable_tensor()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:opencv_tensorflow.AttrValue.ListValue.tensor)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_tensor();
}
inline const ::opencv_tensorflow::TensorProto& AttrValue_ListValue::tensor(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.ListValue.tensor)
  return _internal_tensor().Get(index);
}
inline ::opencv_tensorflow::TensorProto* PROTOBUF_NONNULL AttrValue_ListValue::add_tensor()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::opencv_tensorflow::TensorProto* _add = _internal_mutable_tensor()->Add();
  // @@protoc_insertion_point(field_add:opencv_tensorflow.AttrValue.ListValue.tensor)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorProto>& AttrValue_ListValue::tensor() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opencv_tensorflow.AttrValue.ListValue.tensor)
  return _internal_tensor();
}
inline const ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorProto>&
AttrValue_ListValue::_internal_tensor() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.tensor_;
}
inline ::google::protobuf::RepeatedPtrField<::opencv_tensorflow::TensorProto>* PROTOBUF_NONNULL
AttrValue_ListValue::_internal_mutable_tensor() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.tensor_;
}

// -------------------------------------------------------------------

// AttrValue

// bytes s = 2;
inline bool AttrValue::has_s() const {
  return value_case() == kS;
}
inline void AttrValue::set_has_s() {
  _impl_._oneof_case_[0] = kS;
}
inline void AttrValue::clear_s() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() == kS) {
    _impl_.value_.s_.Destroy();
    clear_has_value();
  }
}
inline const ::std::string& AttrValue::s() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.s)
  return _internal_s();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void AttrValue::set_s(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() != kS) {
    clear_value();

    set_has_s();
    _impl_.value_.s_.InitDefault();
  }
  _impl_.value_.s_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.s)
}
inline ::std::string* PROTOBUF_NONNULL AttrValue::mutable_s()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::std::string* _s = _internal_mutable_s();
  // @@protoc_insertion_point(field_mutable:opencv_tensorflow.AttrValue.s)
  return _s;
}
inline const ::std::string& AttrValue::_internal_s() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  if (value_case() != kS) {
    return ::google::protobuf::internal::GetEmptyStringAlreadyInited();
  }
  return _impl_.value_.s_.Get();
}
inline void AttrValue::_internal_set_s(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() != kS) {
    clear_value();

    set_has_s();
    _impl_.value_.s_.InitDefault();
  }
  _impl_.value_.s_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL AttrValue::_internal_mutable_s() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() != kS) {
    clear_value();

    set_has_s();
    _impl_.value_.s_.InitDefault();
  }
  return _impl_.value_.s_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE AttrValue::release_s() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opencv_tensorflow.AttrValue.s)
  if (value_case() != kS) {
    return nullptr;
  }
  clear_has_value();
  return _impl_.value_.s_.Release();
}
inline void AttrValue::set_allocated_s(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (has_value()) {
    clear_value();
  }
  if (value != nullptr) {
    set_has_s();
    _impl_.value_.s_.InitAllocated(value, GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opencv_tensorflow.AttrValue.s)
}

// int64 i = 3;
inline bool AttrValue::has_i() const {
  return value_case() == kI;
}
inline void AttrValue::set_has_i() {
  _impl_._oneof_case_[0] = kI;
}
inline void AttrValue::clear_i() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() == kI) {
    _impl_.value_.i_ = ::int64_t{0};
    clear_has_value();
  }
}
inline ::int64_t AttrValue::i() const {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.i)
  return _internal_i();
}
inline void AttrValue::set_i(::int64_t value) {
  if (value_case() != kI) {
    clear_value();
    set_has_i();
  }
  _impl_.value_.i_ = value;
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.i)
}
inline ::int64_t AttrValue::_internal_i() const {
  if (value_case() == kI) {
    return _impl_.value_.i_;
  }
  return ::int64_t{0};
}

// float f = 4;
inline bool AttrValue::has_f() const {
  return value_case() == kF;
}
inline void AttrValue::set_has_f() {
  _impl_._oneof_case_[0] = kF;
}
inline void AttrValue::clear_f() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() == kF) {
    _impl_.value_.f_ = 0;
    clear_has_value();
  }
}
inline float AttrValue::f() const {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.f)
  return _internal_f();
}
inline void AttrValue::set_f(float value) {
  if (value_case() != kF) {
    clear_value();
    set_has_f();
  }
  _impl_.value_.f_ = value;
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.f)
}
inline float AttrValue::_internal_f() const {
  if (value_case() == kF) {
    return _impl_.value_.f_;
  }
  return 0;
}

// bool b = 5;
inline bool AttrValue::has_b() const {
  return value_case() == kB;
}
inline void AttrValue::set_has_b() {
  _impl_._oneof_case_[0] = kB;
}
inline void AttrValue::clear_b() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() == kB) {
    _impl_.value_.b_ = false;
    clear_has_value();
  }
}
inline bool AttrValue::b() const {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.b)
  return _internal_b();
}
inline void AttrValue::set_b(bool value) {
  if (value_case() != kB) {
    clear_value();
    set_has_b();
  }
  _impl_.value_.b_ = value;
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.b)
}
inline bool AttrValue::_internal_b() const {
  if (value_case() == kB) {
    return _impl_.value_.b_;
  }
  return false;
}

// .opencv_tensorflow.DataType type = 6;
inline bool AttrValue::has_type() const {
  return value_case() == kType;
}
inline void AttrValue::set_has_type() {
  _impl_._oneof_case_[0] = kType;
}
inline void AttrValue::clear_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() == kType) {
    _impl_.value_.type_ = 0;
    clear_has_value();
  }
}
inline ::opencv_tensorflow::DataType AttrValue::type() const {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.type)
  return _internal_type();
}
inline void AttrValue::set_type(::opencv_tensorflow::DataType value) {
  if (value_case() != kType) {
    clear_value();
    set_has_type();
  }
  _impl_.value_.type_ = value;
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.type)
}
inline ::opencv_tensorflow::DataType AttrValue::_internal_type() const {
  if (value_case() == kType) {
    return static_cast<::opencv_tensorflow::DataType>(_impl_.value_.type_);
  }
  return static_cast<::opencv_tensorflow::DataType>(0);
}

// .opencv_tensorflow.TensorShapeProto shape = 7;
inline bool AttrValue::has_shape() const {
  return value_case() == kShape;
}
inline bool AttrValue::_internal_has_shape() const {
  return value_case() == kShape;
}
inline void AttrValue::set_has_shape() {
  _impl_._oneof_case_[0] = kShape;
}
inline ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NULLABLE AttrValue::release_shape() {
  // @@protoc_insertion_point(field_release:opencv_tensorflow.AttrValue.shape)
  if (value_case() == kShape) {
    clear_has_value();
    auto* temp = reinterpret_cast<::opencv_tensorflow::TensorShapeProto*>(_impl_.value_.shape_);
    if (GetArena() != nullptr) {
      temp = ::google::protobuf::internal::DuplicateIfNonNull(temp);
    }
    _impl_.value_.shape_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::opencv_tensorflow::TensorShapeProto& AttrValue::_internal_shape() const {
  return value_case() == kShape ? *reinterpret_cast<::opencv_tensorflow::TensorShapeProto*>(_impl_.value_.shape_) : reinterpret_cast<::opencv_tensorflow::TensorShapeProto&>(::opencv_tensorflow::_TensorShapeProto_default_instance_);
}
inline const ::opencv_tensorflow::TensorShapeProto& AttrValue::shape() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.shape)
  return _internal_shape();
}
inline ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NULLABLE AttrValue::unsafe_arena_release_shape() {
  // @@protoc_insertion_point(field_unsafe_arena_release:opencv_tensorflow.AttrValue.shape)
  if (value_case() == kShape) {
    clear_has_value();
    auto* temp = reinterpret_cast<::opencv_tensorflow::TensorShapeProto*>(_impl_.value_.shape_);
    _impl_.value_.shape_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void AttrValue::unsafe_arena_set_allocated_shape(
    ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NULLABLE value) {
  // We rely on the oneof clear method to free the earlier contents
  // of this oneof. We can directly use the pointer we're given to
  // set the new value.
  clear_value();
  if (value) {
    set_has_shape();
    _impl_.value_.shape_ = reinterpret_cast<::google::protobuf::Message*>(value);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:opencv_tensorflow.AttrValue.shape)
}
inline ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NONNULL AttrValue::_internal_mutable_shape() {
  if (value_case() != kShape) {
    clear_value();
    set_has_shape();
    _impl_.value_.shape_ = reinterpret_cast<::google::protobuf::Message*>(
        ::google::protobuf::Message::DefaultConstruct<::opencv_tensorflow::TensorShapeProto>(GetArena()));
  }
  return reinterpret_cast<::opencv_tensorflow::TensorShapeProto*>(_impl_.value_.shape_);
}
inline ::opencv_tensorflow::TensorShapeProto* PROTOBUF_NONNULL AttrValue::mutable_shape()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::opencv_tensorflow::TensorShapeProto* _msg = _internal_mutable_shape();
  // @@protoc_insertion_point(field_mutable:opencv_tensorflow.AttrValue.shape)
  return _msg;
}

// .opencv_tensorflow.TensorProto tensor = 8;
inline bool AttrValue::has_tensor() const {
  return value_case() == kTensor;
}
inline bool AttrValue::_internal_has_tensor() const {
  return value_case() == kTensor;
}
inline void AttrValue::set_has_tensor() {
  _impl_._oneof_case_[0] = kTensor;
}
inline ::opencv_tensorflow::TensorProto* PROTOBUF_NULLABLE AttrValue::release_tensor() {
  // @@protoc_insertion_point(field_release:opencv_tensorflow.AttrValue.tensor)
  if (value_case() == kTensor) {
    clear_has_value();
    auto* temp = reinterpret_cast<::opencv_tensorflow::TensorProto*>(_impl_.value_.tensor_);
    if (GetArena() != nullptr) {
      temp = ::google::protobuf::internal::DuplicateIfNonNull(temp);
    }
    _impl_.value_.tensor_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::opencv_tensorflow::TensorProto& AttrValue::_internal_tensor() const {
  return value_case() == kTensor ? *reinterpret_cast<::opencv_tensorflow::TensorProto*>(_impl_.value_.tensor_) : reinterpret_cast<::opencv_tensorflow::TensorProto&>(::opencv_tensorflow::_TensorProto_default_instance_);
}
inline const ::opencv_tensorflow::TensorProto& AttrValue::tensor() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.tensor)
  return _internal_tensor();
}
inline ::opencv_tensorflow::TensorProto* PROTOBUF_NULLABLE AttrValue::unsafe_arena_release_tensor() {
  // @@protoc_insertion_point(field_unsafe_arena_release:opencv_tensorflow.AttrValue.tensor)
  if (value_case() == kTensor) {
    clear_has_value();
    auto* temp = reinterpret_cast<::opencv_tensorflow::TensorProto*>(_impl_.value_.tensor_);
    _impl_.value_.tensor_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void AttrValue::unsafe_arena_set_allocated_tensor(
    ::opencv_tensorflow::TensorProto* PROTOBUF_NULLABLE value) {
  // We rely on the oneof clear method to free the earlier contents
  // of this oneof. We can directly use the pointer we're given to
  // set the new value.
  clear_value();
  if (value) {
    set_has_tensor();
    _impl_.value_.tensor_ = reinterpret_cast<::google::protobuf::Message*>(value);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:opencv_tensorflow.AttrValue.tensor)
}
inline ::opencv_tensorflow::TensorProto* PROTOBUF_NONNULL AttrValue::_internal_mutable_tensor() {
  if (value_case() != kTensor) {
    clear_value();
    set_has_tensor();
    _impl_.value_.tensor_ = reinterpret_cast<::google::protobuf::Message*>(
        ::google::protobuf::Message::DefaultConstruct<::opencv_tensorflow::TensorProto>(GetArena()));
  }
  return reinterpret_cast<::opencv_tensorflow::TensorProto*>(_impl_.value_.tensor_);
}
inline ::opencv_tensorflow::TensorProto* PROTOBUF_NONNULL AttrValue::mutable_tensor()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::opencv_tensorflow::TensorProto* _msg = _internal_mutable_tensor();
  // @@protoc_insertion_point(field_mutable:opencv_tensorflow.AttrValue.tensor)
  return _msg;
}

// .opencv_tensorflow.AttrValue.ListValue list = 1;
inline bool AttrValue::has_list() const {
  return value_case() == kList;
}
inline bool AttrValue::_internal_has_list() const {
  return value_case() == kList;
}
inline void AttrValue::set_has_list() {
  _impl_._oneof_case_[0] = kList;
}
inline void AttrValue::clear_list() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() == kList) {
    if (GetArena() == nullptr) {
      delete _impl_.value_.list_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.value_.list_);
    }
    clear_has_value();
  }
}
inline ::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NULLABLE AttrValue::release_list() {
  // @@protoc_insertion_point(field_release:opencv_tensorflow.AttrValue.list)
  if (value_case() == kList) {
    clear_has_value();
    auto* temp = reinterpret_cast<::opencv_tensorflow::AttrValue_ListValue*>(_impl_.value_.list_);
    if (GetArena() != nullptr) {
      temp = ::google::protobuf::internal::DuplicateIfNonNull(temp);
    }
    _impl_.value_.list_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::opencv_tensorflow::AttrValue_ListValue& AttrValue::_internal_list() const {
  return value_case() == kList ? *reinterpret_cast<::opencv_tensorflow::AttrValue_ListValue*>(_impl_.value_.list_) : reinterpret_cast<::opencv_tensorflow::AttrValue_ListValue&>(::opencv_tensorflow::_AttrValue_ListValue_default_instance_);
}
inline const ::opencv_tensorflow::AttrValue_ListValue& AttrValue::list() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.list)
  return _internal_list();
}
inline ::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NULLABLE AttrValue::unsafe_arena_release_list() {
  // @@protoc_insertion_point(field_unsafe_arena_release:opencv_tensorflow.AttrValue.list)
  if (value_case() == kList) {
    clear_has_value();
    auto* temp = reinterpret_cast<::opencv_tensorflow::AttrValue_ListValue*>(_impl_.value_.list_);
    _impl_.value_.list_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void AttrValue::unsafe_arena_set_allocated_list(
    ::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NULLABLE value) {
  // We rely on the oneof clear method to free the earlier contents
  // of this oneof. We can directly use the pointer we're given to
  // set the new value.
  clear_value();
  if (value) {
    set_has_list();
    _impl_.value_.list_ = reinterpret_cast<::google::protobuf::Message*>(value);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:opencv_tensorflow.AttrValue.list)
}
inline ::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NONNULL AttrValue::_internal_mutable_list() {
  if (value_case() != kList) {
    clear_value();
    set_has_list();
    _impl_.value_.list_ = reinterpret_cast<::google::protobuf::Message*>(
        ::google::protobuf::Message::DefaultConstruct<::opencv_tensorflow::AttrValue_ListValue>(GetArena()));
  }
  return reinterpret_cast<::opencv_tensorflow::AttrValue_ListValue*>(_impl_.value_.list_);
}
inline ::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NONNULL AttrValue::mutable_list()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::opencv_tensorflow::AttrValue_ListValue* _msg = _internal_mutable_list();
  // @@protoc_insertion_point(field_mutable:opencv_tensorflow.AttrValue.list)
  return _msg;
}

// .opencv_tensorflow.NameAttrList func = 10;
inline bool AttrValue::has_func() const {
  return value_case() == kFunc;
}
inline bool AttrValue::_internal_has_func() const {
  return value_case() == kFunc;
}
inline void AttrValue::set_has_func() {
  _impl_._oneof_case_[0] = kFunc;
}
inline void AttrValue::clear_func() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() == kFunc) {
    if (GetArena() == nullptr) {
      delete _impl_.value_.func_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.value_.func_);
    }
    clear_has_value();
  }
}
inline ::opencv_tensorflow::NameAttrList* PROTOBUF_NULLABLE AttrValue::release_func() {
  // @@protoc_insertion_point(field_release:opencv_tensorflow.AttrValue.func)
  if (value_case() == kFunc) {
    clear_has_value();
    auto* temp = reinterpret_cast<::opencv_tensorflow::NameAttrList*>(_impl_.value_.func_);
    if (GetArena() != nullptr) {
      temp = ::google::protobuf::internal::DuplicateIfNonNull(temp);
    }
    _impl_.value_.func_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::opencv_tensorflow::NameAttrList& AttrValue::_internal_func() const {
  return value_case() == kFunc ? *reinterpret_cast<::opencv_tensorflow::NameAttrList*>(_impl_.value_.func_) : reinterpret_cast<::opencv_tensorflow::NameAttrList&>(::opencv_tensorflow::_NameAttrList_default_instance_);
}
inline const ::opencv_tensorflow::NameAttrList& AttrValue::func() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.func)
  return _internal_func();
}
inline ::opencv_tensorflow::NameAttrList* PROTOBUF_NULLABLE AttrValue::unsafe_arena_release_func() {
  // @@protoc_insertion_point(field_unsafe_arena_release:opencv_tensorflow.AttrValue.func)
  if (value_case() == kFunc) {
    clear_has_value();
    auto* temp = reinterpret_cast<::opencv_tensorflow::NameAttrList*>(_impl_.value_.func_);
    _impl_.value_.func_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void AttrValue::unsafe_arena_set_allocated_func(
    ::opencv_tensorflow::NameAttrList* PROTOBUF_NULLABLE value) {
  // We rely on the oneof clear method to free the earlier contents
  // of this oneof. We can directly use the pointer we're given to
  // set the new value.
  clear_value();
  if (value) {
    set_has_func();
    _impl_.value_.func_ = reinterpret_cast<::google::protobuf::Message*>(value);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:opencv_tensorflow.AttrValue.func)
}
inline ::opencv_tensorflow::NameAttrList* PROTOBUF_NONNULL AttrValue::_internal_mutable_func() {
  if (value_case() != kFunc) {
    clear_value();
    set_has_func();
    _impl_.value_.func_ = reinterpret_cast<::google::protobuf::Message*>(
        ::google::protobuf::Message::DefaultConstruct<::opencv_tensorflow::NameAttrList>(GetArena()));
  }
  return reinterpret_cast<::opencv_tensorflow::NameAttrList*>(_impl_.value_.func_);
}
inline ::opencv_tensorflow::NameAttrList* PROTOBUF_NONNULL AttrValue::mutable_func()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::opencv_tensorflow::NameAttrList* _msg = _internal_mutable_func();
  // @@protoc_insertion_point(field_mutable:opencv_tensorflow.AttrValue.func)
  return _msg;
}

// string placeholder = 9;
inline bool AttrValue::has_placeholder() const {
  return value_case() == kPlaceholder;
}
inline void AttrValue::set_has_placeholder() {
  _impl_._oneof_case_[0] = kPlaceholder;
}
inline void AttrValue::clear_placeholder() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() == kPlaceholder) {
    _impl_.value_.placeholder_.Destroy();
    clear_has_value();
  }
}
inline const ::std::string& AttrValue::placeholder() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.AttrValue.placeholder)
  return _internal_placeholder();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void AttrValue::set_placeholder(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() != kPlaceholder) {
    clear_value();

    set_has_placeholder();
    _impl_.value_.placeholder_.InitDefault();
  }
  _impl_.value_.placeholder_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opencv_tensorflow.AttrValue.placeholder)
}
inline ::std::string* PROTOBUF_NONNULL AttrValue::mutable_placeholder()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::std::string* _s = _internal_mutable_placeholder();
  // @@protoc_insertion_point(field_mutable:opencv_tensorflow.AttrValue.placeholder)
  return _s;
}
inline const ::std::string& AttrValue::_internal_placeholder() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  if (value_case() != kPlaceholder) {
    return ::google::protobuf::internal::GetEmptyStringAlreadyInited();
  }
  return _impl_.value_.placeholder_.Get();
}
inline void AttrValue::_internal_set_placeholder(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() != kPlaceholder) {
    clear_value();

    set_has_placeholder();
    _impl_.value_.placeholder_.InitDefault();
  }
  _impl_.value_.placeholder_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL AttrValue::_internal_mutable_placeholder() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() != kPlaceholder) {
    clear_value();

    set_has_placeholder();
    _impl_.value_.placeholder_.InitDefault();
  }
  return _impl_.value_.placeholder_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE AttrValue::release_placeholder() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opencv_tensorflow.AttrValue.placeholder)
  if (value_case() != kPlaceholder) {
    return nullptr;
  }
  clear_has_value();
  return _impl_.value_.placeholder_.Release();
}
inline void AttrValue::set_allocated_placeholder(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (has_value()) {
    clear_value();
  }
  if (value != nullptr) {
    set_has_placeholder();
    _impl_.value_.placeholder_.InitAllocated(value, GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opencv_tensorflow.AttrValue.placeholder)
}

inline bool AttrValue::has_value() const {
  return value_case() != VALUE_NOT_SET;
}
inline void AttrValue::clear_has_value() {
  _impl_._oneof_case_[0] = VALUE_NOT_SET;
}
inline AttrValue::ValueCase AttrValue::value_case() const {
  return AttrValue::ValueCase(_impl_._oneof_case_[0]);
}
// -------------------------------------------------------------------

// -------------------------------------------------------------------

// NameAttrList

// string name = 1;
inline void NameAttrList::clear_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.ClearToEmpty();
  _impl_._has_bits_[0] &= ~0x00000001U;
}
inline const ::std::string& NameAttrList::name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opencv_tensorflow.NameAttrList.name)
  return _internal_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void NameAttrList::set_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_._has_bits_[0] |= 0x00000001U;
  _impl_.name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opencv_tensorflow.NameAttrList.name)
}
inline ::std::string* PROTOBUF_NONNULL NameAttrList::mutable_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:opencv_tensorflow.NameAttrList.name)
  return _s;
}
inline const ::std::string& NameAttrList::_internal_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.name_.Get();
}
inline void NameAttrList::_internal_set_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_._has_bits_[0] |= 0x00000001U;
  _impl_.name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL NameAttrList::_internal_mutable_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_._has_bits_[0] |= 0x00000001U;
  return _impl_.name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE NameAttrList::release_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opencv_tensorflow.NameAttrList.name)
  if ((_impl_._has_bits_[0] & 0x00000001U) == 0) {
    return nullptr;
  }
  _impl_._has_bits_[0] &= ~0x00000001U;
  auto* released = _impl_.name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.name_.Set("", GetArena());
  }
  return released;
}
inline void NameAttrList::set_allocated_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    _impl_._has_bits_[0] |= 0x00000001U;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001U;
  }
  _impl_.name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.name_.IsDefault()) {
    _impl_.name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opencv_tensorflow.NameAttrList.name)
}

// map<string, .opencv_tensorflow.AttrValue> attr = 2;
inline int NameAttrList::_internal_attr_size() const {
  return _internal_attr().size();
}
inline int NameAttrList::attr_size() const {
  return _internal_attr_size();
}
inline void NameAttrList::clear_attr() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.attr_.Clear();
}
inline const ::google::protobuf::Map<::std::string, ::opencv_tensorflow::AttrValue>& NameAttrList::_internal_attr() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.attr_.GetMap();
}
inline const ::google::protobuf::Map<::std::string, ::opencv_tensorflow::AttrValue>& NameAttrList::attr() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_map:opencv_tensorflow.NameAttrList.attr)
  return _internal_attr();
}
inline ::google::protobuf::Map<::std::string, ::opencv_tensorflow::AttrValue>* PROTOBUF_NONNULL NameAttrList::_internal_mutable_attr() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.attr_.MutableMap();
}
inline ::google::protobuf::Map<::std::string, ::opencv_tensorflow::AttrValue>* PROTOBUF_NONNULL NameAttrList::mutable_attr()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_map:opencv_tensorflow.NameAttrList.attr)
  return _internal_mutable_attr();
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace opencv_tensorflow


// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"

#endif  // attr_5fvalue_2eproto_2epb_2eh
